==> foundation-ui-components-1.8.1.tgz: package/src/common/card/NsLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsButton, NsIcon, NsImage, NsLink, NsIconNameType } from '..';

type NsLargeCardProps = {
    title: string;
    subtitle: string;
    intro: string;
    icon: NsIconNameType;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    cardLink: { href: string; title: string };
    isHorizontal?: boolean;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ isHorizontal }) => {
    let width = 'fit-content',
        paddingLeft = '0px',
        justifyContent,
        fontSizeSub = '11px',
        fontSizeTitle = '26px';

    if (isHorizontal) {
        width = '400px';
        paddingLeft = '30px';
        justifyContent = 'space-around';
        fontSizeSub = '16px';
        fontSizeTitle = '36px';
    }
    let direction = isHorizontal ? ('row' as 'row') : ('column' as 'column');

    return {
        display: 'flex',
        flexDirection: direction,
        position: 'relative',
        '.image': {
            width: '375px',
            height: '392px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            width,
            paddingLeft,
            justifyContent,
        },
        '.subtitle': {
            fontSize: fontSizeSub,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: fontSizeTitle,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.cta': {
            display: 'flex',
            flexDirection: 'column' as 'column',
            width: 'fit-content',
            borderBottom: '1px solid black',
            ':hover': {
                opacity: '0.8',
            },
        },
        '.action-link': {
            marginTop: '10px',
            display: 'flex',
            fontWeight: 600,
            ':hover': {
                textDecoration: 'none',
            },
        },
        '.icon': {
            marginLeft: '10px',
        },
    };
});

export default function NsLargeCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    cardLink,
    intro,
    icon,
    isHorizontal,
}: NsLargeCardProps) {
    return (
        <CardContainer role="large-card" component="div" data-testid="large-card" isHorizontal={isHorizontal}>
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                <article className="subtitle">{intro}</article>
                {isHorizontal ? (
                    <div className="cta">
                        <NsLink className="action-link" href={cardLink.href}>
                            {cardLink.title}
                            <NsIcon className="icon" name={icon} />
                        </NsLink>
                    </div>
                ) : (
                    <NsButton
                        className="action-link"
                        variant="outlined"
                        color="primary"
                        href={cardLink.href}
                        fullWidth={false}
                        darkModeEnabled={false}
                    >
                        {cardLink.title}
                    </NsButton>
                )}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.9.1.tgz: package/src/common/card/NsLargeCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsButton, NsIcon, NsImage, NsLink, NsIconNameType } from '..';

type NsLargeCardProps = {
    title: string;
    subtitle?: string;
    intro: string;
    icon?: NsIconNameType;
    buttonVariant: 'text' | 'outlined' | 'contained';
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    cardLink: { href: string; title: string };
    isHorizontal?: boolean;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ isHorizontal }) => {
    let width = '375px',
        paddingLeft = '0px',
        justifyContent,
        fontSizeSub = '16px',
        fontSizeTitle = '26px';

    if (isHorizontal) {
        width = 'unset';
        paddingLeft = '30px';
        justifyContent = 'center';
        fontSizeSub = '16px';
        fontSizeTitle = '36px';
    }
    let direction = isHorizontal ? ('row' as 'row') : ('column' as 'column');

    return {
        display: 'flex',
        flexDirection: direction,
        position: 'relative',
        width,
        '.image': {
            width: '375px',
            height: 'auto',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            paddingLeft,
            justifyContent,
        },
        '.subtitle': {
            fontSize: fontSizeSub,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: fontSizeTitle,
            fontWeight: '400',
            marginTop: '10px',
        },
        '.cta': {
            display: 'flex',
            flexDirection: 'column' as 'column',
            width: 'fit-content',

            borderBottom: '1px solid black',
            ':hover': {
                opacity: '0.8',
            },
        },
        '.action-link': {
            marginTop: '10px',
            display: 'flex',
            fontWeight: 600,
            width: 'fit-content',
            ':hover': {
                textDecoration: 'none',
            },
        },
        '.icon': {
            marginLeft: '10px',
        },
    };
});

export default function NsLargeCard({
    title,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    cardLink,
    buttonVariant,
    intro,
    icon,
    isHorizontal,
}: NsLargeCardProps) {
    return (
        <CardContainer role="large-card" component="div" data-testid="large-card" isHorizontal={isHorizontal}>
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <article className="subtitle">{subtitle}</article>
                <article className="title">{title}</article>
                <article className="subtitle">{intro}</article>
                {isHorizontal ? (
                    <div className="cta">
                        <NsLink className="action-link" href={cardLink.href}>
                            {cardLink.title}
                            <NsIcon className="icon" name={icon} />
                        </NsLink>
                    </div>
                ) : (
                    <NsButton
                        className="action-link"
                        variant={buttonVariant}
                        color="primary"
                        href={cardLink.href}
                        fullWidth={false}
                        darkModeEnabled={false}
                        endIcon={buttonVariant !== 'contained' ? <NsIcon className="icon" name={icon} /> : null}
                    >
                        {cardLink.title}
                    </NsButton>
                )}
            </div>
        </CardContainer>
    );
}
